'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var clientS3 = require('@aws-sdk/client-s3');
var jsCore = require('@lorisleiva/js-core');

class AwsUploader {
  constructor(client, bucketName) {
    this.client = client;
    this.bucketName = bucketName;
  }
  async uploadOne(file) {
    const command = new clientS3.PutObjectCommand({
      Bucket: this.bucketName,
      Key: file.uniqueName,
      Body: file.buffer,
      ContentType: file.contentType || undefined
    });
    await this.client.send(command);
    return this.getUrl(file.uniqueName);
  }
  async upload(files) {
    return Promise.all(files.map(file => this.uploadOne(file)));
  }
  async uploadJson(json) {
    const file = jsCore.createGenericFileFromJson(json);
    const uris = await this.upload([file]);
    return uris[0];
  }
  async getUploadPrice() {
    return jsCore.lamports(0);
  }
  async getUrl(key) {
    const region = await this.client.config.region();
    const encodedKey = encodeURIComponent(key);
    return `https://s3.${region}.amazonaws.com/${this.bucketName}/${encodedKey}`;
  }
}

exports.AwsUploader = AwsUploader;
//# sourceMappingURL=AwsUploader.cjs.map
